@@ -1,6 +1,5 @@
 from __future__ import annotations
 from typing import TYPE_CHECKING
-import abc
 
 if TYPE_CHECKING:
     from .input_source import InputSource
@@ -8,27 +7,23 @@ if TYPE_CHECKING:
     from .data_handler import DataHandler
 
 
-class ChirpType(abc.ABC):
-    @abc.abstractmethod
+class ChirpType:
     def get_processed(self, data_process: DataProcess, data, **kwargs):
         """Gets data processed by a data processor."""
-        pass
+        return None
 
-    @abc.abstractmethod
     def get_handled(self, data_handler: DataHandler, signal, **kwargs):
         """Gets a signal handled by a data handler."""
-        pass
+        return None
 
-    @abc.abstractmethod
     def fetch(self, input_source: InputSource, chirp_source: ChirpSource, **kwargs):
-        pass
+        return None
 
 
-class ChirpSource(abc.ABC):
-    @abc.abstractmethod
+class ChirpSource:
     def get_fetched(self, input_source: InputSource, **kwargs):
         """Gets fetched by an input source."""
-        pass
+        return None
 
 
 class Chirp:
@@ -37,3 +32,6 @@ class Chirp:
     def __init__(self, request_type: ChirpType, source: ChirpSource) -> None:
         self.request_type = request_type
         self.source = source
+
+    def __str__(self) -> str:
+        return f"request_type: {self.request_type} - source: {self.source}"
